#[non_exhaustive]pub struct Voice {
pub endpoint: String,
pub session_id: String,
pub token: String,
}Expand description
The voice payload for the combined server and state to send to lavalink.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: StringThe Discord voice endpoint to connect to.
session_id: StringThe Discord voice session id to authenticate with. This is separate from the session id of lavalink.
token: StringThe Discord voice token to authenticate with.